summaryrefslogtreecommitdiff
path: root/include/users.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/users.h')
-rw-r--r--include/users.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/include/users.h b/include/users.h
index 1fca831ef..a7b6f5629 100644
--- a/include/users.h
+++ b/include/users.h
@@ -360,9 +360,9 @@ public:
}
};
/** Holds a complete list of all channels to which a user has been invited and has not yet joined.
*/
-typedef std::vector<irc::string> InvitedList;
+typedef std::vector< std::pair<irc::string, time_t> > InvitedList;
/** Holds a complete list of all allow and deny tags from the configuration file (connection classes)
*/
@@ -736,8 +736,9 @@ class CoreExport User : public connection
/** Adds a channel to a users invite list (invites them to a channel)
* @param channel A channel name to add
+ * @param timeout When the invite should expire (0 == never)
*/
- virtual void InviteTo(const irc::string &channel);
+ virtual void InviteTo(const irc::string &channel, time_t timeout);
/** Removes a channel from a users invite list.
* This member function is called on successfully joining an invite only channel
@@ -360,9 +360,9 @@ public:
}
};
-/** Holds a complete list of all channels to which a user has been invited and has not yet joined.
+/** Holds a complete list of all channels to which a user has been invited and has not yet joined, and the time at which they'll expire.
*/